#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-Jqk1l0sh5mRKWYV2ysrBVM
key:                  haskell-language-server-2.3.0.0-Jqk1l0sh5mRKWYV2ysrBVM
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  31436f47d5183ad8e6c465511068d169
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-Jqk1l0sh5mRKWYV2ysrBVM
depends:
    aeson-pretty-0.8.10-8b7dXWyHtoo8WzEhToFk3R
    async-2.2.5-IaE93ic7JyB4hqU57sYJnB base-4.18.2.1
    base16-bytestring-1.0.2.0-F2ENaJHYQD5DfLBUhZq65E
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-JhpaldCM2bH4IAZrdYLfyh
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-5KOCgP555FK2eQ73uTKrBZ filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-4WfDNWdvbs978HGuOEpRo5
    githash-0.1.6.3-3JCZjDZoJfm7jEjg3y1NdP
    hie-bios-0.12.0-9Kzp31VezyN3CQTfFKWuDQ
    hiedb-0.4.3.0-6EJ4Rih8n443OnrQBj0qws
    hls-alternate-number-format-plugin-2.3.0.0-7X2QafP3VNyKnVVZ0Fqnpi
    hls-cabal-fmt-plugin-2.3.0.0-5d3ajJ3KiFSE8PO8g9CiNd
    hls-cabal-plugin-2.3.0.0-4uYSSsvdQ65I8N8V82daeU
    hls-call-hierarchy-plugin-2.3.0.0-pvVdO1kV9UBVk9mBDnZv1
    hls-change-type-signature-plugin-2.3.0.0-LZ89Getm3j68WELY2TP8WW
    hls-class-plugin-2.3.0.0-G8CTPamkZSYGNLmWXsmoPL
    hls-code-range-plugin-2.3.0.0-6VQtAi6NWXvE8aWbp0TXj6
    hls-eval-plugin-2.3.0.0-Gv1gQlCqV674TjRtIOgSn0
    hls-explicit-fixity-plugin-2.3.0.0-CKToC5MMPvY1R1V9k60oQQ
    hls-explicit-imports-plugin-2.3.0.0-3Owms0PSf58GstGC62fysW
    hls-explicit-record-fields-plugin-2.3.0.0-12MYw1R6FYALkO5Ppv0HD2
    hls-fourmolu-plugin-2.3.0.0-CtlS502n1vI7xyIOHpD3dW
    hls-gadt-plugin-2.3.0.0-IbLZYaGQL4H1K28zyRkjva
    hls-graph-2.3.0.0-Dwp4mrhjHCyGH7wYWnrCby
    hls-hlint-plugin-2.3.0.0-E2F9jfluK2y7L69246fuEI
    hls-module-name-plugin-2.3.0.0-5BrjZZh6jo57eulu9O1PWi
    hls-ormolu-plugin-2.3.0.0-HETRF9qqVhg3qhMpYEVtvO
    hls-overloaded-record-dot-plugin-2.3.0.0-HRlyVdpbwMqK8NaC46aYCf
    hls-plugin-api-2.3.0.0-21dgaLnGjvU4x9vzlj6c31
    hls-pragmas-plugin-2.3.0.0-JsMDc23PqcxD3EkRnOWKB
    hls-qualify-imported-names-plugin-2.3.0.0-DZyWjNIYwOS9sJ2riPFLxu
    hls-refactor-plugin-2.3.0.0-6Mws0XlLera5nD0ve7GNKW
    hls-rename-plugin-2.3.0.0-2BZ8CbjYqGMHTB4NIvXfce
    hls-retrie-plugin-2.3.0.0-HyeK7st2jZPHIAx4POjVc5
    hls-splice-plugin-2.3.0.0-FVIRRWUQGKB1X5IJdxBv1R
    hls-stylish-haskell-plugin-2.3.0.0-AuVNWu62zT6D680q4NWoRs
    lsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw
    optparse-applicative-0.18.1.0-CGpmSA88Tyw9bqabWV8H20
    optparse-simple-0.1.1.4-E41oK03yXSxJAchtbBnVaS
    prettyprinter-1.7.1-S0Vgm51rIvLDdfgcsiFYb process-1.6.19.0
    safe-exceptions-0.1.7.4-GNNPztToXdoWhvcp0xRTC
    sqlite-simple-0.4.19.0-GTQdZbj9yxj4iqTKOsIhDr text-2.0.2
    unordered-containers-0.2.20.1-1lWFLFb7qnGGdfGyTf5Bys

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

